# This is so that you can import ppack or import average from ppack
# in stead of from ppack.functions import average...........

from .decorators import singleton
from .functions import listChunker, report, weirdCase
